16.64. cdist-type__install_chroot_umount(7) — cdist 6.9.4 documentation

# 16.64. cdist-type__install_chroot_umount(7)

## 16.64.1. NAME

cdist-type__install_chroot_umount - unmount a chroot mounted by __install_chroot_mount

## 16.64.2. DESCRIPTION

Undo what __install_chroot_mount did.

## 16.64.3. REQUIRED PARAMETERS

None

## 16.64.4. OPTIONAL PARAMETERS

None

## 16.64.5. EXAMPLES

    __install_chroot_umount /path/to/chroot

## 16.64.6. SEE ALSO

cdist-type__install_chroot_mount(7)

## 16.64.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.64.8. COPYING

Copyright (C) 2012 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.